@@ -11,6 +11,8 @@ AlbumWindow::AlbumWindow(QWidget *parent, QString token) :
     ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
     connect(ui->actionUpload_photo, SIGNAL(triggered()), this, SLOT(uploadPhoto()));
+    connect(ui->actionDownload_all_photos, SIGNAL(triggered()), this, SLOT(downloadAllPhotos()));
+    ui->statusBar->hide();
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
@@ -31,7 +33,11 @@ void AlbumWindow::browseAlbum(QString id, QString albumCount)
 void AlbumWindow::uploadPhoto()
 {
     ImageUploadDialog *dialog = new ImageUploadDialog(this);
+#ifdef Q_WS_S60
+    dialog->showMaximized();
+#else
     dialog->show();
+#endif
 }
 
 void AlbumWindow::updateAlbum()
@@ -58,6 +64,7 @@ void AlbumWindow::onReplyReceived()
 
     foreach (PhotoItem *item, photos) {
         ui->gridLayout->removeWidget(item);
+        sourceLinks.clear();
         delete item;
     }
 
@@ -89,6 +96,7 @@ void AlbumWindow::onReplyReceived()
             else if (imageUrl.endsWith("a.jpg"))
                 mediumUrl = imageUrl;
         }
+        sourceLinks.append(normalUrl);
         PhotoItem *item = new PhotoItem(this, accessToken, nam);
         item->setComments(jsonData.toMap().value("comments").toMap().value("data").toList());
         item->setTags(jsonData.toMap().value("tags").toMap().value("data").toList());
@@ -128,3 +136,65 @@ void AlbumWindow::onPhotoItemClicked(PhotoItem *item)
     photo->show();
 #endif
 }
+
+void AlbumWindow::downloadAllPhotos()
+{
+    if (sourceLinks.isEmpty()) {
+#ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(this, tr("Unable to download: album is empty"));
+#else
+        QMessageBox::warning(this, tr("Error"), tr("Unable to download: album is empty"));
+#endif
+        return;
+    }
+
+    setAttribute(Qt::WA_DeleteOnClose, false);
+    m_finishedDownloads = 0;
+    m_imagesCount = sourceLinks.count();
+    m_downloadLocation = QFileDialog::getExistingDirectory(this, tr("Select folder to save images to"),
+                                                           QDir::homePath());
+    if (m_downloadLocation.isEmpty()) {
+        setAttribute(Qt::WA_DeleteOnClose, true);
+        return;
+    }
+
+    if (ui->statusBar->isHidden())
+        ui->statusBar->show();
+    ui->statusBar->showMessage(tr("%1/%2 photos downloaded").arg(m_finishedDownloads, m_imagesCount));
+
+    foreach (QString url, sourceLinks) {
+        QNetworkReply *reply = nam->get(QNetworkRequest(url));
+        connect(reply, SIGNAL(finished()), this, SLOT(onDownloadFinished()));
+    }
+}
+
+void AlbumWindow::onDownloadFinished()
+{
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QString url = reply->url().toString();
+    int pos = url.lastIndexOf("/");
+    QString baseName = url.remove(0, pos);
+    baseName.remove("/");
+    QString fileName = m_downloadLocation + "/" + baseName;
+    QFile image(fileName, this);
+    if (image.open(QFile::WriteOnly)) {
+        image.write(reply->readAll());
+        image.close();
+    }
+    m_finishedDownloads++;
+
+    ui->statusBar->showMessage(tr("%1/%2 photos downloaded").arg(m_finishedDownloads, m_imagesCount));
+
+    if (m_finishedDownloads == m_imagesCount) {
+#ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(this, tr("Download complete"));
+#else
+        QMessageBox::information(this, tr("Success"), tr("Album downloaded"));
+#endif
+        setAttribute(Qt::WA_DeleteOnClose, true);
+        ui->statusBar->hide();
+        if (!isVisible())
+            this->deleteLater();
+        return;
+    }
+}
