@@ -3,6 +3,7 @@
 
 #include <QDialog>
 #include <QDebug>
+#include <QDesktopWidget>
 #include <qfacebook.h>
 
 namespace Ui {
@@ -36,11 +37,13 @@ private:
     QString m_locationString;
     QFacebook *qfacebook;
     QFacebookReply *reply;
+    QVariant m_locations;
 
 private slots:
     void refreshPlaces();
     void onReplyReceived();
     void accept();
+    void orientationChanged();
 };
 
 #endif // CHECKINDIALOG_H
