@@ -14,8 +14,8 @@
 #include <QApplication>
 #include <QStyleOptionViewItem>
 
-enum UserRoles {UserRoleValueText,
-                UserRoleUserId};
+enum DisplayRoles {UserRoleValueText,
+                   UserRoleUserId};
 
 class ThumbnailItemDelegate : public QStyledItemDelegate
 {
