@@ -10,10 +10,18 @@ MessagesWindow::MessagesWindow(QWidget *parent, QString token) :
 {
     ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
+    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+    this->orientationChanged();
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
     this->updateMessages();
+    bool whiteMode = QSettings().value("main/white-mode", false).toBool();
+    if (whiteMode) {
+        QPalette p(palette());
+        p.setColor(QPalette::Background, QColor(220, 225, 235));
+        setPalette(p);
+    }
 }
 
 MessagesWindow::~MessagesWindow()
@@ -31,6 +39,12 @@ void MessagesWindow::updateMessages()
 #endif
 }
 
+void MessagesWindow::orientationChanged()
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    ui->scrollAreaWidgetContents->setMaximumWidth(screenGeometry.width()-10);
+}
+
 void MessagesWindow::onReplyReceived()
 {
     if (this->reply->error() != QNetworkReply::NoError) {
@@ -53,12 +67,14 @@ void MessagesWindow::onReplyReceived()
     foreach(jsonData, listData) {
         NewsFeedPost *item = new NewsFeedPost(this, accessToken, qfacebook, nam);
         item->setMessageMode(true);
-        item->setDeletable(true);
+        /* Messages are readonly for now... */
+        // item->setDeletable(true);
         connect(item, SIGNAL(clicked(QString)), this, SLOT(onMessageClicked(QString)));
         QString from = jsonData.toMap().value("from").toMap().value("name").toString();
         QString userId = jsonData.toMap().value("from").toMap().value("id").toString();
         QString id = jsonData.toMap().value("id").toString();
         QString message = jsonData.toMap().value("message").toString();
+        QString time = jsonData.toMap().value("updated_time").toString();
         if (message.size() > 100) {
             message.truncate(100);
             message.append("...");
@@ -66,6 +82,7 @@ void MessagesWindow::onReplyReceived()
         item->setUserId(userId);
         item->setName(from);
         item->setMessage(message);
+        item->setTime(time);
         item->getPixmapFromUrl(QString("https://graph.facebook.com/%1/picture&access_token=%2").arg(userId, accessToken));
         item->setId(id);
         ui->scrollLayout->addWidget(item);
@@ -80,11 +97,19 @@ void MessagesWindow::onMessageClicked(QString id)
 {
     MessageView *message = new MessageView(this, this->accessToken);
     message->parseMessageById(id);
+#ifdef Q_WS_S60
+    message->showMaximized();
+#else
     message->show();
+#endif
 }
 
 void MessagesWindow::onNewMessageButtonClicked()
 {
     ComposeMessage *messageComposer = new ComposeMessage(this, this->accessToken);
+#ifdef Q_WS_S60
+    messageComposer->showMaximized();
+#else
     messageComposer->show();
+#endif
 }
