@@ -1,14 +1,19 @@
 #include "notificationsdialog.h"
 #include "ui_notificationsdialog.h"
+#include "systemnotification.h"
+
+SystemNotification *m_notifier = 0;
 
 NotificationsDialog::NotificationsDialog(QWidget *parent, QString token) :
     QDialog(parent),
     ui(new Ui::NotificationsDialog),
     accessToken(token),
-    nam(new QNetworkAccessManager(this))
+    nam(new QNetworkAccessManager(this)),
+    qfacebook(new QFacebook(token, this))
 {
     ui->setupUi(this);
     isFetching = false;
+    m_notifier = new SystemNotification(this);
     this->orientationChanged();
     this->updateNotifications();
     this->getNoficiationCount();
@@ -17,6 +22,7 @@ NotificationsDialog::NotificationsDialog(QWidget *parent, QString token) :
 
 NotificationsDialog::~NotificationsDialog()
 {
+    m_notifier->clearNotifications();
     delete ui;
 }
 
@@ -95,6 +101,12 @@ void NotificationsDialog::onNotificationsListReceived()
         return;
     }
 
+    QByteArray notificationsArray = reply->readAll();
+    if (notificationsArray == m_notifications)
+        return;
+    else
+        m_notifications = notificationsArray;
+
     if (!notificationItems.isEmpty()) {
         foreach (NotificationItem *item, notificationItems) {
             ui->layout->removeWidget(item);
@@ -104,7 +116,7 @@ void NotificationsDialog::onNotificationsListReceived()
     }
 
     QList< QMap<QString,QString> > notifications;
-    QXmlStreamReader xml(reply->readAll());
+    QXmlStreamReader xml(notificationsArray);
 
     while (!xml.atEnd() && !xml.hasError()) {
         QXmlStreamReader::TokenType token = xml.readNext();
@@ -177,21 +189,30 @@ void NotificationsDialog::addElementDataToMap(QXmlStreamReader& xml, QMap<QStrin
 void NotificationsDialog::addNotificationsToUi(QList< QMap<QString,QString> >& notifications)
 {
     unreadCount = 0;
+    m_unreadNotifications.clear();
+    m_notifier->clearNotifications();
     while (!notifications.isEmpty()) {
         QMap<QString,QString> notification = notifications.takeFirst();
         QString text = notification["title_text"];
         if (!text.isEmpty()) {
             NotificationItem *item = new NotificationItem(this, accessToken, nam);
+            connect(item, SIGNAL(markedAsRead(NotificationItem*)), this, SLOT(onMarkedAsRead(NotificationItem*)));
             connect(item, SIGNAL(clicked(NotificationItem*)), this, SLOT(onNotificationClicked(NotificationItem*)));
             item->setObjectId(notification["object_id"]);
             item->setObjectType(notification["object_type"]);
             item->setUserId(notification["sender_id"]);
             item->setText(notification["title_text"]);
+            item->setNotificationId(notification["notification_id"]);
             bool isUnread = false;
             if (notification["is_unread"].toInt() == 1) {
                 isUnread = true;
+                m_unreadNotifications.append(item);
+                m_notifier->createNotification("Facebook", item->text(), "general_facebook");
+                m_notifier->vibrate();
                 unreadCount++;
             }
+            if (unreadCount > 0)
+                m_notifier->createSoundNotification();
             item->setUnread(isUnread);
             ui->layout->addWidget(item);
             notificationItems.append(item);
@@ -202,26 +223,62 @@ void NotificationsDialog::addNotificationsToUi(QList< QMap<QString,QString> >& n
 
 void NotificationsDialog::onNotificationClicked(NotificationItem *item)
 {
-    this->close();
+    item->markAsRead();
     QString type = item->objectType();
     if (type == "stream") {
         SinglePostWindow *post = new SinglePostWindow(this->parentWidget(), accessToken);
         post->loadPost(item->objectId());
+#ifdef Q_WS_S60
+        post->showMaximized();
+#else
         post->show();
+#endif
     } else if (type == "group") {
         ProfileWindow *group = new ProfileWindow(this->parentWidget(), accessToken);
         group->browseProfile(item->objectId());
         group->setWindowTitle(tr("Group"));
+#ifdef Q_WS_S60
+        group->showMaximized();
+#else
         group->show();
+#endif
     } else if (type == "photo") {
         PhotoWindow *photo = new PhotoWindow(this->parentWidget(), accessToken);
         photo->showPhotoFromId(item->objectId());
         photo->setWindowTitle(tr("Photo"));
+#ifdef Q_WS_S60
+        photo->showMaximized();
+#else
         photo->show();
+#endif
+    } else if (type == "friend") {
+        ProfileWindow *profile = new ProfileWindow(this->parentWidget(), accessToken);
+        profile->browseProfile(item->objectId());
+        profile->setWindowTitle(tr("Profile"));
+#ifdef Q_WS_S60
+        profile->showMaximized();
+#else
+        profile->show();
+#endif
     }
 }
 
+void NotificationsDialog::markRead()
+{
+    foreach (NotificationItem *item, m_unreadNotifications) {
+        item->markAsRead();
+    }
+}
+
+void NotificationsDialog::onMarkedAsRead(NotificationItem *item)
+{
+    m_unreadNotifications.removeOne(item);
+    emit gotNotificationsCount(m_unreadNotifications.count());
+}
+
 void NotificationsDialog::showEvent(QShowEvent *)
 {
     this->updateNotifications();
+    // Delay setting as read for a while, gives the user a chance to see which notificaions were unread
+    this->markRead();
 }
