@@ -1,5 +1,6 @@
 #include "eventitem.h"
 #include "ui_eventitem.h"
+#include "profilewindow.h"
 
 EventItem::EventItem(QWidget *parent, QString token, QNetworkAccessManager *nam) :
     QWidget(parent),
@@ -13,6 +14,9 @@ EventItem::EventItem(QWidget *parent, QString token, QNetworkAccessManager *nam)
     p.setColor(QPalette::Foreground, p.highlight().color());
     ui->nameLabel->setPalette(p);
     connect(ui->rsvpBox, SIGNAL(activated(int)), this, SLOT(onRsvpChanged(int)));
+    connect(ui->attendeesButton, SIGNAL(clicked()), this, SLOT(onAttendeesButtonClicked()));
+    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+    this->orientationChanged();
 }
 
 EventItem::~EventItem()
@@ -48,7 +52,10 @@ void EventItem::setName(QString name)
 
 void EventItem::setLocation(QString location)
 {
-    ui->locationLabel->setText(location);
+    if (location.isEmpty())
+        ui->locationLabel->hide();
+    else
+        ui->locationLabel->setText(location);
 }
 
 void EventItem::setUserId(QString id)
@@ -142,3 +149,56 @@ void EventItem::onRsvpReplyReceived()
     if (ui->rsvpBox->count() == 4)
         ui->rsvpBox->removeItem(3);
 }
+
+void EventItem::onAttendeesButtonClicked()
+{
+    ui->attendeesButton->blockSignals(true);
+    attendingReply = qfacebook->getObject(m_eventId + "/attending");
+    if (attendingReply)
+        connect(attendingReply, SIGNAL(finished()), this, SLOT(onAttendeesReplyReceived()));
+}
+
+void EventItem::onAttendeesReplyReceived()
+{
+    QDialog *dialog = new QDialog(this);
+    QVBoxLayout *layout = new QVBoxLayout(dialog);
+    QListWidget *listWidget = new QListWidget(this);
+    connect(listWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onAttendeeClicked(QListWidgetItem*)));
+    layout->addWidget(listWidget);
+    dialog->setLayout(layout);
+    dialog->setMinimumHeight(600);
+
+    QVariant jsonData = attendingReply->data();
+    QVariantList listData = jsonData.toMap().value("data").toList();
+    foreach (jsonData, listData) {
+        QListWidgetItem *item = new QListWidgetItem(listWidget);
+        item->setData(Qt::UserRole, jsonData.toMap().value("id").toString());
+        item->setText(jsonData.toMap().value("name").toString());
+    }
+    dialog->setWindowTitle(tr("Attendees"));
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->show();
+    ui->attendeesButton->blockSignals(false);
+}
+
+void EventItem::onAttendeeClicked(QListWidgetItem *item)
+{
+    ProfileWindow *profile = new ProfileWindow(this, accessToken);
+    profile->setWindowTitle(item->text());
+    profile->browseProfile(item->data(Qt::UserRole).toString());
+#ifdef Q_WS_S60
+    profile->showMaximized();
+#else
+    profile->show();
+#endif
+}
+
+void EventItem::orientationChanged()
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    if (screenGeometry.width() > screenGeometry.height()) {
+        ui->layout->setDirection(QBoxLayout::LeftToRight);
+    } else {
+        ui->layout->setDirection(QBoxLayout::TopToBottom);
+    }
+}
