@@ -8,6 +8,10 @@
 #include <QMap>
 #include <QDebug>
 #include <QDateTime>
+#include <QDesktopWidget>
+#include <QListWidget>
+#include <QListWidgetItem>
+#include <QDialog>
 
 namespace Ui {
     class EventItem;
@@ -37,6 +41,7 @@ private:
     QFacebook *qfacebook;
     QFacebookReply *reply;
     QFacebookReply *rsvpReply;
+    QFacebookReply *attendingReply;
     QMap<QString,QString> attending;
     QMap<QString,QString> maybeAttending;
     QMap<QString,QString> notAttending;
@@ -50,6 +55,10 @@ private slots:
     void updateAttendees();
     void onRsvpChanged(int);
     void onRsvpReplyReceived();
+    void orientationChanged();
+    void onAttendeesButtonClicked();
+    void onAttendeesReplyReceived();
+    void onAttendeeClicked(QListWidgetItem *item);
 };
 
 #endif // EVENTITEM_H
